Migrating to Koji 1.29
======================

You should consider the following changes when migrating to 1.29:

DB Updates
----------

There is no schema change this time.

As in previous releases, we provide a migration script which is no-op in this case.

Other changes
-------------

There are numerous other changes in 1.29 that should not have a direct impact on migration. For
details see: :doc:`../release_notes/release_notes_1.29`
